From 8e880edd0a3e8e8cf05743b8f7b47e81dd9f08bf Mon Sep 17 00:00:00 2001
From: Timothy Pearson <kb9vqf@pearsoncomputing.net>
Date: Sun, 6 Nov 2011 02:23:33 -0600
Subject: Additional kde to tde renaming

---
 ChangeLog            | 32 ++++++++++++++++----------------
 Makefile.am          |  4 ++--
 README               |  4 ++--
 acinclude.m4         | 26 +++++++++++++-------------
 configure.in         |  4 ++--
 configure.in.in      |  2 +-
 doc/en/Makefile.am   |  2 +-
 doc/en/index.docbook | 22 +++++++++++-----------
 kdesudo/Makefile.am  | 16 ++++++++--------
 kdesudo/kdesudo.cpp  | 18 +++++++++---------
 kdesudo/kdesudo.h    |  2 +-
 kdesudo/main.cpp     | 12 ++++++------
 po/fr.po             | 16 ++++++++--------
 subdirs              |  2 +-
 14 files changed, 81 insertions(+), 81 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index c880b99..1e9fe8b 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -26,20 +26,20 @@ KdeSudo 2.2
   due to sudo removing some environment variables, causing
   failure to use current dcopserver.
 
-kdesudo 2.1
+tdesudo 2.1
 -----------
 * Args parsing improved, to be compatible with gksu:
   - Support now complicated command with parsed args
 
 * Uses kprocess instead of shell process:
-  - kdesudo now supports processes detaching themselves
+  - tdesudo now supports processes detaching themselves
 
-* Make -t a fake option for kdesu compatibility again:
+* Make -t a fake option for tdesu compatibility again:
   - there is no point hiding StdOut...
 
 * Code cleanup
 
-kdesudo 2.0
+tdesudo 2.0
 -----------
 * Args parsing mostly rewritten, fixes potential security issues.
 
@@ -47,45 +47,45 @@ kdesudo 2.0
 
 * "-s" option (aka -k for sudo) now works due to PTY connexion
 
-* Option "-n" option isn't fake option for kdesu cmdline
+* Option "-n" option isn't fake option for tdesu cmdline
     compatibility anymore, and uses "nice" to set command priority.
 
-* Added option "-r" for kdesu cmdline compatibility, uses
+* Added option "-r" for tdesu cmdline compatibility, uses
     "nice" to force process priority to 50/100 (default)
 
-* Added support for -t kdesu cmdline option, for terminal output
+* Added support for -t tdesu cmdline option, for terminal output
 
-* Added support for -f kdesu cmdline option
+* Added support for -f tdesu cmdline option
 
-* Added support for -n kdesu cmdline option, for non storing the password
+* Added support for -n tdesu cmdline option, for non storing the password
 
-* Added support for -r and -p kdesu cmdline option, for "nice" support
+* Added support for -r and -p tdesu cmdline option, for "nice" support
 
 * KdeSudo closes correctly after 3 bad passwords given
 
 * Fixes kcm modules support
 
-kdesudo 1.4
+tdesudo 1.4
 -----------
 * Removed debug code for -c option
 
-kdesudo 1.3
+tdesudo 1.3
 -----------
 * Change to using xauth to dynamically generate xauth-keys.
   Frode M. Døving <frode@ubuntu.com>
 
-* Fix vulnerability issue, as kdesudo didn't quote args
+* Fix vulnerability issue, as tdesudo didn't quote args
   correctly.
 
-kdesudo 1.2
+tdesudo 1.2
 -----------
 * Don't use the user's $HOME, potentially corrupts files
 
-kdesudo 1.1
+tdesudo 1.1
 -----------
 * Fixed code to work with a mdern version of sudo
 
-kdesudo 1.0
+tdesudo 1.0
 -----------
 * Initial public release
 
diff --git a/Makefile.am b/Makefile.am
index c8c6cf4..d040040 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -1,8 +1,8 @@
 ####### kdevelop will overwrite this part!!! (begin)##########
 
-SUBDIRS = kdesudo po doc 
+SUBDIRS = tdesudo po doc 
 
-EXTRA_DIST = kdesudo.kdevprj admin AUTHORS COPYING ChangeLog INSTALL README TODO kdesudo.lsm 
+EXTRA_DIST = tdesudo.kdevprj admin AUTHORS COPYING ChangeLog INSTALL README TODO tdesudo.lsm 
 
 ####### kdevelop will overwrite this part!!! (end)############
 # not a GNU package. You can remove this line, if 
diff --git a/README b/README
index 31627a3..aa6bbdb 100644
--- a/README
+++ b/README
@@ -1,2 +1,2 @@
-Just type "kdesudo <command>" to run <command> as root user.
-Optionally you can type "kdesudo -u <runas> <command>" and <command> will be executed as user <runas>
+Just type "tdesudo <command>" to run <command> as root user.
+Optionally you can type "tdesudo -u <runas> <command>" and <command> will be executed as user <runas>
diff --git a/acinclude.m4 b/acinclude.m4
index c411c68..7ccd126 100644
--- a/acinclude.m4
+++ b/acinclude.m4
@@ -371,7 +371,7 @@ AC_DEFUN([KDE_1_CHECK_PATHS],
   fi
 
 AC_MSG_CHECKING([for KDE libraries installed])
-ac_link='$LIBTOOL_SHELL --silent --mode=link ${CXX-g++} -o conftest $CXXFLAGS $all_includes $CPPFLAGS $LDFLAGS $all_libraries conftest.$ac_ext $LIBS -lkdecore $LIBQT $KDE_TEST_RPATH 1>&5'
+ac_link='$LIBTOOL_SHELL --silent --mode=link ${CXX-g++} -o conftest $CXXFLAGS $all_includes $CPPFLAGS $LDFLAGS $all_libraries conftest.$ac_ext $LIBS -ltdecore $LIBQT $KDE_TEST_RPATH 1>&5'
 
 if AC_TRY_EVAL(ac_link) && test -s conftest; then
   AC_MSG_RESULT(yes)
@@ -710,7 +710,7 @@ AC_SUBST(kde_templatesdir)
 AC_SUBST(kde_servicesdir)
 AC_SUBST(kde_servicetypesdir)
 AC_SUBST(kde_moduledir)
-AC_SUBST(kdeinitdir, '$(kde_moduledir)')
+AC_SUBST(tdeinitdir, '$(kde_moduledir)')
 AC_SUBST(kde_styledir)
 AC_SUBST(kde_widgetdir)
 if test "$kde_qtver" = 1; then
@@ -2064,12 +2064,12 @@ AC_DEFUN([KDE_CREATE_LIBS_ALIASES],
 
 if test $kde_qtver = 3; then
    case $host in
-               *cygwin*) lib_kded="-lkdeinit_kded" ;;
+               *cygwin*) lib_kded="-ltdeinit_kded" ;;
                *) lib_kded="" ;;
        esac
    AC_SUBST(LIB_KDED, $lib_kded)
-   AC_SUBST(LIB_KDECORE, "-lkdecore")
-   AC_SUBST(LIB_KDEUI, "-lkdeui")
+   AC_SUBST(LIB_KDECORE, "-ltdecore")
+   AC_SUBST(LIB_KDEUI, "-ltdeui")
    AC_SUBST(LIB_KIO, "-lkio")
    AC_SUBST(LIB_KJS, "-lkjs")
    AC_SUBST(LIB_SMB, "-lsmb")
@@ -2078,9 +2078,9 @@ if test $kde_qtver = 3; then
    AC_SUBST(LIB_KHTML, "-lkhtml")
    AC_SUBST(LIB_KSPELL, "-lkspell")
    AC_SUBST(LIB_KPARTS, "-lkparts")
-   AC_SUBST(LIB_KDEPRINT, "-lkdeprint")
+   AC_SUBST(LIB_KDEPRINT, "-ltdeprint")
    AC_SUBST(LIB_KUTILS, "-lkutils")
-   AC_SUBST(LIB_KDEPIM, "-lkdepim")
+   AC_SUBST(LIB_KDEPIM, "-ltdepim")
    AC_SUBST(LIB_KIMPROXY, "-lkimproxy")
    AC_SUBST(LIB_KNEWSTUFF, "-lknewstuff")
    AC_SUBST(LIB_KDNSSD, "-lkdnssd")
@@ -2089,8 +2089,8 @@ if test $kde_qtver = 3; then
    AC_SUBST(LIB_KSYCOCA, "-lkio")
    AC_SUBST(LIB_KFILE, "-lkio")
 elif test $kde_qtver = 2; then
-   AC_SUBST(LIB_KDECORE, "-lkdecore")
-   AC_SUBST(LIB_KDEUI, "-lkdeui")
+   AC_SUBST(LIB_KDECORE, "-ltdecore")
+   AC_SUBST(LIB_KDEUI, "-ltdeui")
    AC_SUBST(LIB_KIO, "-lkio")
    AC_SUBST(LIB_KSYCOCA, "-lksycoca")
    AC_SUBST(LIB_SMB, "-lsmb")
@@ -2099,10 +2099,10 @@ elif test $kde_qtver = 2; then
    AC_SUBST(LIB_KHTML, "-lkhtml")
    AC_SUBST(LIB_KSPELL, "-lkspell")
    AC_SUBST(LIB_KPARTS, "-lkparts")
-   AC_SUBST(LIB_KDEPRINT, "-lkdeprint")
+   AC_SUBST(LIB_KDEPRINT, "-ltdeprint")
 else
-   AC_SUBST(LIB_KDECORE, "-lkdecore -lXext $(LIB_QT)")
-   AC_SUBST(LIB_KDEUI, "-lkdeui $(LIB_KDECORE)")
+   AC_SUBST(LIB_KDECORE, "-ltdecore -lXext $(LIB_QT)")
+   AC_SUBST(LIB_KDEUI, "-ltdeui $(LIB_KDECORE)")
    AC_SUBST(LIB_KFM, "-lkfm $(LIB_KDECORE)")
    AC_SUBST(LIB_KFILE, "-lkfile $(LIB_KFM) $(LIB_KDEUI)")
    AC_SUBST(LIB_KAB, "-lkab $(LIB_KIMGIO) $(LIB_KDECORE)")
@@ -2489,7 +2489,7 @@ if eval "test \"`echo $ac_cv_lib_gif`\" = yes"; then
   AC_MSG_RESULT(yes)
   AC_DEFINE_UNQUOTED(HAVE_LIBGIF, 1, [Define if you have libgif])
 else
-  AC_MSG_ERROR(You need giflib30. Please install the kdesupport package)
+  AC_MSG_ERROR(You need giflib30. Please install the tdesupport package)
 fi
 ])
 
diff --git a/configure.in b/configure.in
index 2c862c6..0d76132 100644
--- a/configure.in
+++ b/configure.in
@@ -40,7 +40,7 @@ dnl Perform program name transformation
 AC_ARG_PROGRAM
 
 dnl Automake doc recommends to do this only here. (Janos)
-AM_INIT_AUTOMAKE(kdesudo, 2.5.1) dnl searches for some needed programs
+AM_INIT_AUTOMAKE(tdesudo, 2.5.1) dnl searches for some needed programs
 
 KDE_SET_PREFIX
 
@@ -78,7 +78,7 @@ KDE_CREATE_SUBDIRSLIST
 AC_CONFIG_FILES([ Makefile ])
 AC_CONFIG_FILES([ doc/Makefile ])
 AC_CONFIG_FILES([ doc/en/Makefile ])
-AC_CONFIG_FILES([ kdesudo/Makefile ])
+AC_CONFIG_FILES([ tdesudo/Makefile ])
 AC_CONFIG_FILES([ po/Makefile ])
 AC_OUTPUT
 # Check if KDE_SET_PREFIX was called, and --prefix was passed to configure
diff --git a/configure.in.in b/configure.in.in
index f2ae2cc..0d52fe2 100644
--- a/configure.in.in
+++ b/configure.in.in
@@ -1,6 +1,6 @@
 #MIN_CONFIG(3)
 
-AM_INIT_AUTOMAKE(kdesudo,2.5.1)
+AM_INIT_AUTOMAKE(tdesudo,2.5.1)
 
 dnl CXXFLAGS="$NOOPT_CXXFLAGS" dnl __kdevelop[noopt]__
 dnl CFLAGS="$NOOPT_CFLAGS" dnl __kdevelop[noopt]__
diff --git a/doc/en/Makefile.am b/doc/en/Makefile.am
index 4a4bf71..c7faf6b 100644
--- a/doc/en/Makefile.am
+++ b/doc/en/Makefile.am
@@ -6,6 +6,6 @@ EXTRA_DIST = index.docbook
 ####### kdevelop will overwrite this part!!! (end)############
 
 KDE_LANG = en
-KDE_DOCS = kdesudo
+KDE_DOCS = tdesudo
 
 
diff --git a/doc/en/index.docbook b/doc/en/index.docbook
index 62b8041..b98ee8d 100644
--- a/doc/en/index.docbook
+++ b/doc/en/index.docbook
@@ -1,7 +1,7 @@
 <?xml version="1.0" ?>
 <!DOCTYPE book PUBLIC "-//KDE//DTD DocBook XML V4.1-Based Variant V1.0//EN" "dtd/kdex.dtd" [
-  <!ENTITY kdesudo '<application>kdesudo</application>'>
-  <!ENTITY kappname "&kdesudo;">
+  <!ENTITY tdesudo '<application>tdesudo</application>'>
+  <!ENTITY kappname "&tdesudo;">
   <!ENTITY package "kdebase">
   <!ENTITY % addindex "IGNORE">
   <!ENTITY % English "INCLUDE" > <!-- change language only here -->
@@ -10,7 +10,7 @@
 <book lang="&language;">
 <bookinfo>
 
-<title>The &kdesudo; handbook</title>
+<title>The &tdesudo; handbook</title>
 
 <authorgroup>
 <author>
@@ -34,7 +34,7 @@
 <releaseinfo>1.00.00</releaseinfo>
 
 
-<abstract><para>&kdesudo; is a graphical front end for the
+<abstract><para>&tdesudo; is a graphical front end for the
 <command>sudo</command> command.</para></abstract>
 
 <keywordset>
@@ -49,10 +49,10 @@
 <chapter id="introduction">
 <title>Introduction</title>
 
-<para>Welcome to &kdesudo;! &kdesudo; is a graphical front end for the
+<para>Welcome to &tdesudo;! &tdesudo; is a graphical front end for the
 <command>su</command> command for the K Desktop Environment.
 It allows you to run a program as different user if the sys admin allows
-it. &kdesudo; is an unprivileged program; it uses
+it. &tdesudo; is an unprivileged program; it uses
 the system's <command>sudo</command> command.</para>
 
 <para>This program is meant to be started from the command line or
@@ -60,13 +60,13 @@ from <filename>.desktop</filename> files.</para>
 
 </chapter>
 
-<chapter id="using-kdesu">
-<title>Using &kdesudo;</title>
+<chapter id="using-tdesu">
+<title>Using &tdesudo;</title>
 
-<para>Usage of &kdesudo; is easy. The syntax is like this:</para>
+<para>Usage of &tdesudo; is easy. The syntax is like this:</para>
 
     <cmdsynopsis>
-      <command>kdesudo</command>
+      <command>tdesudo</command>
       <arg>-u <replaceable>RUNAS</replaceable></arg>
       <arg>COMMAND</arg>
     </cmdsynopsis>
@@ -93,7 +93,7 @@ is specified at RUNAS</para></listitem>
 <chapter id="Author">
 <title>Author</title>
 
-<para>&kdesudo;</para>
+<para>&tdesudo;</para>
 
 <para>Copyright 2003 Robert Gruber</para>
 
diff --git a/kdesudo/Makefile.am b/kdesudo/Makefile.am
index b8d1b96..354f75a 100644
--- a/kdesudo/Makefile.am
+++ b/kdesudo/Makefile.am
@@ -1,13 +1,13 @@
 ####### kdevelop will overwrite this part!!! (begin)##########
-bin_PROGRAMS = kdesudo
+bin_PROGRAMS = tdesudo
 
 ## INCLUDES were found outside kdevelop specific part
 
-kdesudo_SOURCES = kdesudo.cpp main.cpp 
-kdesudo_LDADD   =  $(LIB_QT) $(LIB_KDECORE) $(LIB_KDEUI)  $(LIBSOCKET) -lkdesu
+tdesudo_SOURCES = tdesudo.cpp main.cpp 
+tdesudo_LDADD   =  $(LIB_QT) $(LIB_KDECORE) $(LIB_KDEUI)  $(LIBSOCKET) -ltdesu
 
 
-EXTRA_DIST = main.cpp kdesudo.cpp kdesudo.h
+EXTRA_DIST = main.cpp tdesudo.cpp tdesudo.h
 
 install-data-local:
 
@@ -41,12 +41,12 @@ INCLUDES= $(all_includes)
 METASOURCES = AUTO
 
 # the library search path. 
-kdesudo_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+tdesudo_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 
 # Uncomment the following two lines if you add a ui.rc file for your application to make use of
 # KDE?s XML GUI builing
-#rcdir = $(kde_datadir)/kdesudo
-#rc_DATA = kdesudoui.rc
+#rcdir = $(kde_datadir)/tdesudo
+#rc_DATA = tdesudoui.rc
 
 #WARNING: if you use a ui.rc file above, use:
 
@@ -59,6 +59,6 @@ kdesudo_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE)
 messages: 
 	LIST=`find . -name \*.h -o -name \*.hh -o -name \*.H -o -name \*.hxx -o -name \*.hpp -o -name \*.cpp -o -name \*.cc -o -name \*.cxx -o -name \*.ecpp -o -name \*.C`; \
 	if test -n "$$LIST"; then \
-	 $(XGETTEXT) $$LIST -o $(podir)/kdesudo.pot; \
+	 $(XGETTEXT) $$LIST -o $(podir)/tdesudo.pot; \
 	fi
 
diff --git a/kdesudo/kdesudo.h b/kdesudo/kdesudo.h
index 46451d3..61b4f13 100644
--- a/kdesudo/kdesudo.h
+++ b/kdesudo/kdesudo.h
@@ -1,5 +1,5 @@
 /***************************************************************************
-                          kdesudo.cpp  -  description
+                          tdesudo.cpp  -  description
                              -------------------
     begin                : Sam Feb 15 15:42:12 CET 2003
     copyright            : (C) 2003 by Robert Gruber <rgruber@users.sourceforge.net>
diff --git a/kdesudo/main.cpp b/kdesudo/main.cpp
index c02dfac..9fa63f1 100644
--- a/kdesudo/main.cpp
+++ b/kdesudo/main.cpp
@@ -1,5 +1,5 @@
 /***************************************************************************
-                          kdesudo.cpp  -  description
+                          tdesudo.cpp  -  description
                              -------------------
     begin                : Sam Feb 15 15:42:12 CET 2003
     copyright            : (C) 2003 by Robert Gruber <rgruber@users.sourceforge.net>
@@ -25,7 +25,7 @@
 #include <kaboutdata.h>
 #include <klocale.h>
 
-#include "kdesudo.h"
+#include "tdesudo.h"
 #include <kmessagebox.h>
 #include <kdesktopfile.h>
 #include <kiconloader.h>
@@ -63,7 +63,7 @@ static KCmdLineOptions options[] =
 
 int main(int argc, char **argv)
 {
-	KAboutData aboutData("kdesudo", I18N_NOOP("KdeSudo"),
+	KAboutData aboutData("tdesudo", I18N_NOOP("KdeSudo"),
 		VERSION, description, KAboutData::License_GPL,
 		"(c) 2007-2008, Anthony Mercatante", 0, 0, "tonio@ubuntu.com");
 	aboutData.addAuthor("Robert Gruber",0, "rgruber@users.sourceforge.net");
@@ -98,7 +98,7 @@ int main(int argc, char **argv)
 	}
 
 	if ((!args->isSet("c")) && (!args->count())) {
-		kdError() << I18N_NOOP("You must provide the name of the executable you want to run as an argument to kdesudo") << endl;
+		kdError() << I18N_NOOP("You must provide the name of the executable you want to run as an argument to tdesudo") << endl;
 		exit(1);
 	}
 
@@ -140,9 +140,9 @@ int main(int argc, char **argv)
 	else
 		name = executable;
 
-	KdeSudo *kdesudo = new KdeSudo(0,0,icon,name,withIgnoreButton);
+	KdeSudo *tdesudo = new KdeSudo(0,0,icon,name,withIgnoreButton);
 
-	a.setMainWidget(kdesudo);
+	a.setMainWidget(tdesudo);
 	args->clear();
 
 	return a.exec();
diff --git a/po/fr.po b/po/fr.po
index f3b94ca..d94381d 100644
--- a/po/fr.po
+++ b/po/fr.po
@@ -34,36 +34,36 @@ msgstr "Commentaire à afficher dans la boite de dialogue"
 #: main.cpp:72
 msgid ""
 "No command arguments supplied!\n"
-"Usage: kdesudo [-u <runas>] <command>\n"
+"Usage: tdesudo [-u <runas>] <command>\n"
 "KdeSudo will now exit..."
 msgstr ""
 "Aucune commande spécifiée en argument!\n"
-"Utilisation: kdesudo [-u <runas>] <command>\n"
+"Utilisation: tdesudo [-u <runas>] <command>\n"
 "KdeSudo va maintenant se fermer..."
 
-#: kdesudo.cpp:28
+#: tdesudo.cpp:28
 msgid ""
 "<b>%1</b> needs administrative privileges. Please enter your password for "
 "verification."
 msgstr "<b>%1</b> a besoin des droits d'administration. Merci de saisir votre mot de passe pour vérification."
 
-#: kdesudo.cpp:72
+#: tdesudo.cpp:72
 msgid "Wrong password, try again!"
 msgstr "Mot de passe erroné, veuillez réessayer!"
 
-#: kdesudo.cpp:77
+#: tdesudo.cpp:77
 msgid "Command not found!"
 msgstr "Commande inexistante!"
 
-#: kdesudo.cpp:83
+#: tdesudo.cpp:83
 msgid "Your username is unknown to sudo!"
 msgstr "Votre nom d'utilisateur est inconnu de sudo!"
 
-#: kdesudo.cpp:89
+#: tdesudo.cpp:89
 msgid "Your user is not allowed to run the specified command!"
 msgstr "Vous n'avez pas le droit d'exécuter la commande spécifiée!"
 
-#: kdesudo.cpp:95 kdesudo.cpp:101
+#: tdesudo.cpp:95 tdesudo.cpp:101
 msgid "Your user is not allowed to run sudo on this host!"
 msgstr "Vous n'avez pas le droit d'exécuter sudo sud l'hôte spécifié!"
 
diff --git a/subdirs b/subdirs
index 1726784..ec945f3 100644
--- a/subdirs
+++ b/subdirs
@@ -1,3 +1,3 @@
 doc
-kdesudo
+tdesudo
 po
diff --git a/kdesudo/kdesudo.cpp b/kdesudo/kdesudo.cpp
index 15cd74f..5649da6 100644
--- a/kdesudo/kdesudo.cpp
+++ b/kdesudo/kdesudo.cpp
@@ -1,5 +1,5 @@
 /***************************************************************************
-                          kdesudo.cpp  -  description
+                          tdesudo.cpp  -  description
                              -------------------
     begin                : Sam Feb 15 15:42:12 CET 2003
     copyright            : (C) 2003 by Robert Gruber <rgruber@users.sourceforge.net>
@@ -19,7 +19,7 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "kdesudo.h"
+#include "tdesudo.h"
 
 #include <tqfile.h>
 #include <tqdir.h>
@@ -32,7 +32,7 @@
 #include <kpushbutton.h>
 #include <kpassdlg.h>
 #include <kstandarddirs.h>
-#include <kdesu/kcookie.h>
+#include <tdesu/kcookie.h>
 #include <kdebug.h>
 #include <kshell.h>
 #include <ktempfile.h>
@@ -70,7 +70,7 @@ KdeSudo::KdeSudo(TQWidget *parent, const char *name,const TQString& icon, const
 
 	if (!args->isSet("c") && !args->count() && (!args->isSet("s")))
 	{
-		KMessageBox::information(NULL, i18n("No command arguments supplied!\nUsage: kdesudo [-u <runas>] <command>\nKdeSudo will now exit..."));
+		KMessageBox::information(NULL, i18n("No command arguments supplied!\nUsage: tdesudo [-u <runas>] <command>\nKdeSudo will now exit..."));
 		noExec = true;
 	}
 
@@ -120,7 +120,7 @@ KdeSudo::KdeSudo(TQWidget *parent, const char *name,const TQString& icon, const
 		setButtonText(User1, i18n("&Ignore"));
 	}
 
-	// Apologies for the C code, taken from kdelibs/kdesu/kdesu_stub.c
+	// Apologies for the C code, taken from kdelibs/tdesu/tdesu_stub.c
 	// KControl and other places need to use the user's existing DCOP server
 	// For that we set DCOPSERVER.  Create a file in /tmp and use iceauth to add magic cookies
 	// from the existing server and set ICEAUTHORITY to point to the file
@@ -141,7 +141,7 @@ KdeSudo::KdeSudo(TQWidget *parent, const char *name,const TQString& icon, const
 		tempfile = mkstemp(iceauthority);
 		umask(oldumask);
 		if (tempfile == -1) {
-			kdError() << "error in kdesudo mkstemp" << endl;
+			kdError() << "error in tdesudo mkstemp" << endl;
 			exit(1);
 		} else {
 			// close(tempfile); //FIXME why does this make the connect() call later crash?
@@ -152,7 +152,7 @@ KdeSudo::KdeSudo(TQWidget *parent, const char *name,const TQString& icon, const
 	
 		fout = popen("iceauth >/dev/null 2>&1", "w");
 		if (!fout) {
-			kdError() << "error in kdesudo running iceauth" << endl;
+			kdError() << "error in tdesudo running iceauth" << endl;
 			exit(1);
 		}
 		fprintf(fout, "add ICE \"\" %s %s\n", host, auth);
@@ -178,7 +178,7 @@ KdeSudo::KdeSudo(TQWidget *parent, const char *name,const TQString& icon, const
 	// Default cookie-timeout is 60 sec. .
 	// 'man xauth' for more info on xauth cookies.
 	
-	KTempFile temp = KTempFile("/tmp/kdesudo-","-xauth");
+	KTempFile temp = KTempFile("/tmp/tdesudo-","-xauth");
 	m_tmpname = temp.name();
 	
 	FILE *f;
@@ -197,7 +197,7 @@ KdeSudo::KdeSudo(TQWidget *parent, const char *name,const TQString& icon, const
 	}
 	
 	// non root users need to be able to read the xauth file.
 	// the xauth file is deleted when kdesudo exits. security?
 	TQFile tf(m_tmpname);
 	if (!runas.isEmpty() && runas != "root" && tf.exists())
 		chmod(m_tmpname.ascii(),0644);
@@ -197,7 +197,7 @@ KdeSudo::KdeSudo(TQWidget *parent, const char *name,const TQString& icon, const
 	
 	// non root users need to be able to read the xauth file.
-	// the xauth file is deleted when kdesudo exits. security?
+	// the xauth file is deleted when tdesudo exits. security?
 	TQFile tf(m_tmpname);
 	if (!runas.isEmpty() && runas != "root" && tf.exists())
-- 
cgit v1.2.3

